@@ -7,5 +7,6 @@ from .core.plug import Plug
 from .core.schema import (Any, Invalid, JSONSchema, Nullable, Optional, Schema, SchemaError,
                           Validator, Walker)
 from .core.stream import PlugStream
-from .core.util import (escape, pretty_str, resolve_import, unescape, ConfigProperty, Configurable,
-                        HTTPOpenable, IDGen, LocalFilter, OpenState, Openable)
+from .core.util import (escape, pretty_str, resolve_import, unescape, ConfigProperty,
+                        Configurable, HTTPOpenable, IDGen, LocalFilter, OpenState, Openable,
+                        Watchable, WatchedDict, WatchedList)
