@@ -22,6 +22,8 @@ This is a simple control panel to add or update plugs and hooks in a running sys
 
 from asyncio import gather
 from collections import defaultdict
+from importlib import import_module
+from inspect import cleandoc
 import json
 import re
 import logging
@@ -57,7 +59,7 @@ class WebUIHook(immp.ResourceHook):
                                                              # `zip` doesn't seem to work.
                                                              "zipped": zip})
         # Home:
-        self.ctx.route("GET", "", self.noop, "main.j2", "main")
+        self.ctx.route("GET", "", self.main, "main.j2", "main")
         # Add:
         self.ctx.route("GET", "add", self.noop, "add.j2", "add")
         self.ctx.route("POST", "add", self.add, "add.j2", "add:post")
@@ -107,6 +109,13 @@ class WebUIHook(immp.ResourceHook):
     async def noop(self, request):
         return {}
 
+    async def main(self, request):
+        loggers = ([("<root>", logging.getLevelName(logging.root.level))] +
+                   [(module, logging.getLevelName(logger.level))
+                    for module, logger in sorted(logging.root.manager.loggerDict.items())
+                    if isinstance(logger, logging.Logger) and logger.level != logging.NOTSET])
+        return {"loggers": loggers}
+
     async def add(self, request):
         post = await request.post()
         try:
@@ -124,6 +133,7 @@ class WebUIHook(immp.ResourceHook):
             return {"path": path,
                     "config": config,
                     "class": cls,
+                    "doc": cleandoc(import_module(cls.__module__).__doc__),
                     "hook": issubclass(cls, immp.Hook)}
         try:
             name = post["name"]
@@ -174,6 +184,7 @@ class WebUIHook(immp.ResourceHook):
             title = await immp.Channel(plug, source).title()
             name = re.sub(r"[^a-z0-9]+", "-", title, flags=re.I).strip("-") if title else ""
         return {"plug": plug,
+                "doc": cleandoc(import_module(plug.__module__).__doc__),
                 "add_name": name,
                 "add_source": source,
                 "channels": {name: channel for name, channel in self.host.channels.items()
@@ -425,6 +436,7 @@ class WebUIHook(immp.ResourceHook):
         hook = self._resolve_hook(request)
         can_stop = not isinstance(hook, (WebHook, WebUIHook))
         return {"hook": hook,
+                "doc": cleandoc(import_module(hook.__module__).__doc__),
                 "resource": isinstance(hook, immp.ResourceHook),
                 "priority": self.host.priority.get(hook.name),
                 "can_stop": can_stop}
